
# TP SAREK



Sarek is an automatic worflow based on nextflow (workflow manager) which is part of the nf-core.

nf-core if a collection of standardised workflow, tested and maintained by expert : [https://nf-co.re/](https://nf-co.re/)

nf-core provide many workflow for various omic sequences:
- methylseq
- atacseq
- rnaseq
- ...

    

Sarek is dedicated to variant detection.



Nextflow allow also to control the informatic environment in particular the version of each tool to use. The dependencies management is based on singularity/conda. It allows to reproduce result on any IT infrastructure.



Advantages of nf-core is that you do not need to justify the method you use. On the contrary, as nf-core became the standard and very popular solution, you may have to justify your choice not to use standard workflow.



Note: this file will be stored here: [https://forgemia.inra.fr/gibbs-biostatinfo/coding-tutorials/-/tree/main/CR](https://forgemia.inra.fr/gibbs-biostatinfo/coding-tutorials/-/tree/main/CR)



## Initial file format and pre-processing

**(1) fasta**: sequence ATTCGAGC... + header

```
>sequence_id
ACTGCTGGG...
```

**(2) fastq**: fasta with a quality score as a letter  : [https://en.wikipedia.org/wiki/FASTQ\_format](https://en.wikipedia.org/wiki/FASTQ\_format)

```
@sequence_id
ACTGCTGGG...
+
(***+))%%...
```


quality characters can be encoded by different "alphabet", but it is normally automatically recognised by bioinformatics tools.



fastq1 and fastq2 because paired reads (both extremities of one DNA fragment) 



**(3)quality check, trimming and filtering**: 

- removing low quality bases 

quality typically decreases at the end of each reads, but they are actually expected to be good enough

one tool to check sequence quality is FastQC : [https://www.bioinformatics.babraham.ac.uk/projects/fastqc/](https://www.bioinformatics.babraham.ac.uk/projects/fastqc/)

simplest command line : `fastqc file1.fastq file2.fastq`
or in interactive mode


- removal of sequences from the adapter (with a known library)


fastp ([https://github.com/OpenGene/fastp)](https://github.com/OpenGene/fastp)) is a tool to trim and filter reads on quality/adapter/length... parameters



## Main process : mapping and variant detection

**(4) mapping**: 

around 90-95% of reads should be correctly mapped:
- positioned on the reference genome
- with correct orientation (--> and <--) 
- with expected distance between pair, which should globally correspond to the size of the initial DNA fragment.

Mapping can be done with tools like bwa or bowtie (trimmed fastq files) 

fastq1 + fastq2 + reference genome sequence --> **BAM** file

duplicate identification:  [https://gatk.broadinstitute.org/hc/en-us/articles/360037052812-MarkDuplicates-Picard](https://gatk.broadinstitute.org/hc/en-us/articles/360037052812-MarkDuplicates-Picard)

Duplicates can arise during sample preparation e.g. sequencing library construction using PCR, or during clustering definition (on  sequencing chip). Duplicates are tagged in the BAM file, or removed.

Base quality recalibration: useful when samples come from different sequencing ; a set of known SNPs is needed. It allows to better differenciate a sequencing error from a true biological variant.


**(5) variant detection**

Find differences between reference genome and reads in the BAM file, piling up the reads, and indicating the level of confidence.

Tools: GATK haplotype caller, DeepVariant, FreeBayes 

nf\_core uses by default GATK haplotype caller ([https://gatk.broadinstitute.org/hc/en-us)](https://gatk.broadinstitute.org/hc/en-us))


results are in a **vcf** file summing up all the information. VCF file list only difference from the reference.

problem :

To optimise informatic ressources, detection is made sample by sample (bam by bam), so you get one VCF file per sample. VCF file became a problem as it only include difference from each sample but you can not be sure of the genotype in other reference position, so you can not easily combine VCF from different samples.

Solution: 

use **gvcf** files, which include genotype of all loci

Finally, a **Genomic DB** can be created. It corresponds to a compilation of all gVCF, and allow to generate a multi-sample VCF


## SAREK

ssh -XY username@genobioinfo.toulouse.inrae.fr

(-X flag is to open a graphical interface, -Y flag enables trusted X11 forwarding)

fasq file



Getting cattle genome reference fasta file from Ensembl, if needed (see [https://www.ensembl.org/Bos\_taurus/Info/Index)](https://www.ensembl.org/Bos\_taurus/Info/Index)):

wget [https://ftp.ensembl.org/pub/release-113/fasta/bos\_taurus/dna/Bos\_taurus.ARS-UCD1.3.dna.toplevel.fa.gz](https://ftp.ensembl.org/pub/release-113/fasta/bos\_taurus/dna/Bos\_taurus.ARS-UCD1.3.dna.toplevel.fa.gz)



Preparing short files for the example:

zcat filename.fastq.gz | head -n 10000 | gzip -c > newname.fastq.gz

for file in `ls *.gz`;do echo $file;done;



workflow inputs (format depends on the workflow version):
* sample sheet: where to find all the necessary files
ex:
`sample_name,sample_id,sequencing_lane,fastq_1,fastq_2`
* reference genome fasta file
* profile  file : which allow to indicate IT parameters you will use (cluster type, preconfigure IT ressources, singularity environment...). There is an official genotoul bioinfo cluster file : [https://nf-co.re/configs/genotoul/](https://nf-co.re/configs/genotoul/)


All parameters (input included) may be provided through a configuration file or in command line.

The nextflow command is then:

```
nextflow run nf-core/sarek -r 3.1.2 -profile singularity,genotoul -c parameters.config -w nextfolw_work_directory --outdir results_directory
```

  `-r` allow to precise the version of the sarek workflow <br>
  `-profile` the specific genotoul IT configuration <br>
  `-w` and `--outdir` correspond to temporary and final results respectively


Additionally you may use:<br>
  `-resume` to re-run it without erasing the previous run

The sarek parameters include <br>
  - "biological parameters" : input, reference genome, specific tool names and associated parameters <br>
  - "workflow parameters" : which step to run or ignore : <br>
`--step mapping` will configure the starting point to the mapping step ([https://nf-co.re/sarek/3.4.2/parameters/#step)](https://nf-co.re/sarek/3.4.2/parameters/#step)) <br>
`--skip_tools baserecalibrator` allow to avoid the recalibration step. ([https://nf-co.re/sarek/3.4.2/parameters/#skip\_tools)](https://nf-co.re/sarek/3.4.2/parameters/#skip\_tools))


There are a lot of different sarek parameters:  [https://nf-co.re/sarek/3.4.2/parameters/](https://nf-co.re/sarek/3.4.2/parameters/)

One particularly usefull is `--joint_germline`. As mentionned before analysing multiple sample need to call variant on all sample together (and not by sample). Is means that we need to tell Sarek to generate gvcf files, the genomic DB ans finally the multi-samples VCF file.

If you want to identify structural variant you may be interested to change the variantcaller from haplotypecaller to manta. To do this you may use the `--tools` option ([https://nf-co.re/sarek/3.4.2/parameters/#tools)](https://nf-co.re/sarek/3.4.2/parameters/#tools))



**Outputs**
(Additionnally to the VCF file)

multiQC report: agregates and illustrates reports from many of the tools (quality score along reads,...) 

nextflow report: time used for every step, and memory alocation (so you can adjust the memory alocated at each process in the next run)

dag: all steps done and rules used










